FastZeroizable

Trait FastZeroizable 

pub trait FastZeroizable {
    // Required method
    fn fast_zeroize(&mut self);
}
Trait for types that can be zeroized at runtime.

This trait is dyn-compatible, allowing it to be used in trait objects like &mut dyn FastZeroizable.

Use this trait when you need dynamic dispatch for zeroization operations.

Required Methods

fn fast_zeroize(&mut self)

Zeroizes the value in place.

After calling this method, all sensitive data should be overwritten with zeros.

Implementations on Foreign Types

Source

impl FastZeroizable for bool

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for char

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for f32

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for f64

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for i8

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for i16

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for i32

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for i64

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for i128

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for isize

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for u8

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for u16

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for u32

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for u64

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for u128

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for ()

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for usize

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for String

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for AtomicBool

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for AtomicI8

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for AtomicI16

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for AtomicI32

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for AtomicI64

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for AtomicIsize

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for AtomicU8

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for AtomicU16

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for AtomicU32

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for AtomicU64

Source

fn fast_zeroize(&mut self)

Source

impl FastZeroizable for AtomicUsize

Source

fn fast_zeroize(&mut self)

Source

impl<T> FastZeroizable for *const T

Source

fn fast_zeroize(&mut self)

Source

impl<T> FastZeroizable for *mut T

Source

fn fast_zeroize(&mut self)

Source

impl<T> FastZeroizable for [T]

Source

fn fast_zeroize(&mut self)

Source

impl<T: FastZeroizable> FastZeroizable for Option<T>

Source

fn fast_zeroize(&mut self)

Source

impl<T: FastZeroizable> FastZeroizable for Box<T>

Source

fn fast_zeroize(&mut self)

Source

impl<T: ZeroizeMetadata + FastZeroizable> FastZeroizable for Vec<T>

Source

fn fast_zeroize(&mut self)

Source

impl<T: ZeroizeMetadata + FastZeroizable, const N: usize> FastZeroizable for [T; N]

Source

fn fast_zeroize(&mut self)

Implementors