pub trait FastZeroizable {
// Required method
fn fast_zeroize(&mut self);
}Expand description
Trait for types that can be zeroized at runtime.
This trait is dyn-compatible, allowing it to be used in trait objects
like &mut dyn FastZeroizable.
Use this trait when you need dynamic dispatch for zeroization operations.
Required Methods
Sourcefn fast_zeroize(&mut self)
fn fast_zeroize(&mut self)
Zeroizes the value in place.
After calling this method, all sensitive data should be overwritten with zeros.